@@ -1,7 +1,6 @@
-var fs = require("fs"),
+var fs = require("fs").promises,
     path = require("path"),
     tape = require("tape"),
-    queue = require("d3-queue"),
     d3 = require("../");
 
 tape("formatLocale({decimal: decimal}) observes the specified decimal point", function(test) {
@@ -86,30 +85,15 @@ tape("formatLocale({nan: nan}) observes the specified not-a-number representatio
   test.end();
 });
 
-tape("locale data is valid", function(test) {
-  fs.readdir("locale", function(error, locales) {
-    if (error) throw error;
-    var q = queue.queue(1);
-    locales.forEach(function(locale) {
-      if (!/\.json$/i.test(locale)) return;
-      q.defer(testLocale, path.join("locale", locale));
-    });
-    q.awaitAll(function(error) {
-      if (error) throw error;
-      test.end();
-    });
-  });
-
-  function testLocale(locale, callback) {
-    fs.readFile(locale, "utf8", function(error, locale) {
-      if (error) return void callback(error);
-      locale = JSON.parse(locale);
-      test.equal("currency" in locale, true);
-      test.equal("decimal" in locale, true);
-      test.equal("grouping" in locale, true);
-      test.equal("thousands" in locale, true);
-      locale = d3.formatLocale(locale);
-      callback(null);
-    });
+tape("locale data is valid", async function(test) {
+  for (const file of await fs.readdir("locale")) {
+    if (!/\.json$/i.test(file)) continue;
+    const locale = JSON.parse(await fs.readFile(path.join("locale", file), "utf8"));
+    test.equal("currency" in locale, true);
+    test.equal("decimal" in locale, true);
+    test.equal("grouping" in locale, true);
+    test.equal("thousands" in locale, true);
+    d3.formatLocale(locale);
   }
+  test.end();
 });
